@@ -1,7 +1,7 @@
 package Regexp::IPv4;
 
 our $DATE = '2016-10-18'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -28,11 +28,11 @@ Regexp::IPv4 - Regular expression for IPv4 addresses
 
 =head1 VERSION
 
-This document describes version 0.002 of Regexp::IPv4 (from Perl distribution Regexp-IPv4), released on 2016-10-18.
+This document describes version 0.003 of Regexp::IPv4 (from Perl distribution Regexp-IPv4), released on 2016-10-18.
 
 =head1 SYNOPSIS
 
- use Regexp::IPvv qw($IPvv_re);
+ use Regexp::IPv4 qw($IPv4_re);
 
  $address =~ /^$IPv4_re$/ and print "IPv4 address\n";
 
